#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-7yJAKu30vsXF6t9qKoPBAn
key:                  infer-license-0.2.0-7yJAKu30vsXF6t9qKoPBAn
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  f31bd400528d80d392dfc561d2cf74ec
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-7yJAKu30vsXF6t9qKoPBAn
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1 text-2.0.2
    text-metrics-0.3.3-99aLZTeZaTEHsF5zqMeX4G

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

